@@ -4,10 +4,10 @@ from typing import Callable, Dict, Optional, Union
 from cognite.client._api.datapoints import DatapointsAPI
 from cognite.client._api.files import FilesAPI
 from cognite.client._api_client import APIClient
-from cognite.client._cognite_client import CogniteClient as Client
+from cognite.client.beta import CogniteClient as Client
+from cognite.experimental._api.annotations import AnnotationsAPI
 from cognite.experimental._api.assets import ExperimentalAssetsAPI
 from cognite.experimental._api.document_parsing import DocumentParsingAPI
-from cognite.experimental._api.entity_extraction import EntityExtractionAPI
 from cognite.experimental._api.entity_matching import EntityMatchingAPI
 from cognite.experimental._api.functions import FunctionsAPI
 from cognite.experimental._api.model_hosting import ModelHostingAPI
@@ -26,7 +26,6 @@ class ExperimentalFilesApi(FilesAPI):
 
 
 APIClient.RETRYABLE_POST_ENDPOINTS |= {
-    "/timeseries/synthetic/query",
     "/files/unstructured/search",
     "/files/unstructured/downloadlink/parsed",
 }
@@ -87,18 +86,20 @@ class CogniteClient(Client):
             disable_pypi_version_check,
             debug,
         )
-        self.relationships = RelationshipsAPI(self._config, api_version="playground", cognite_client=self)
+        # OLD relationships - planned to be removed soon
+        self.relationships_playground = RelationshipsAPI(self._config, api_version="playground", cognite_client=self)
+        # NEW assets features - e.g. types
+        self.assets_playground = ExperimentalAssetsAPI(self._config, api_version="playground", cognite_client=self)
+
         self.files = ExperimentalFilesApi(self._config, api_version="v1", cognite_client=self)
         self.model_hosting = ModelHostingAPI(self._config, api_version="playground", cognite_client=self)
-
-        self.assets_playground = ExperimentalAssetsAPI(self._config, api_version="playground", cognite_client=self)
         self.types = TypesAPI(self._config, api_version="playground", cognite_client=self)
 
         self.document_parsing = DocumentParsingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_matching = EntityMatchingAPI(self._config, api_version="playground", cognite_client=self)
-        self.entity_extraction = EntityExtractionAPI(self._config, api_version="playground", cognite_client=self)
         self.pnid_parsing = PNIDParsingAPI(self._config, api_version="playground", cognite_client=self)
         self.schemas = SchemaCompletionAPI(self._config, api_version="playground", cognite_client=self)
         self.pnid_object_detection = PNIDObjectDetectionAPI(self._config, api_version="playground", cognite_client=self)
+        self.annotations = AnnotationsAPI(self._config, api_version="playground", cognite_client=self)
 
         self.functions = FunctionsAPI(self.config, api_version="playground", cognite_client=self)
